********************************************************************************
** Company      : Fidus Systems
** Date         : 07/25/2012
** Designer     : Javier Rodriguez Molina
** Contact      : j.rodriguez.molina@fidus.com
** Design Name  : DC1564A 14 bit ADC
** File Name    : linear_1564a.sdc
** Hardware     : Stratix IV development board DK-DEV-4SGX230N
** Description  :
** Time constraints for DC1564A-G 14 bit ADC design
********************************************************************************

#*******************************************************************************
# Time Information
#*******************************************************************************

set_time_format -unit ns -decimal_places 3


#*******************************************************************************
# Create Clock
#*******************************************************************************

#SignalTap II clock
create_clock -name {altera_reserved_tck} -period 100.000 -waveform { 0.000 50.000 } [get_ports {altera_reserved_tck}]
#Main Input clock
create_clock -name {clk1} -period 3.225 -waveform { 0.000 1.667 } [get_ports { CLK_IN }]


#*******************************************************************************
# Create Generated Clock
#*******************************************************************************

#derive pll clocks
create_generated_clock -name {ext_pll_inst|altpll_component|auto_generated|pll1|clk[0]} -source [get_pins {ext_pll_inst|altpll_component|auto_generated|pll1|inclk[0]}] -duty_cycle 50.000 -multiply_by 2 -phase -180.000 -master_clock {clk1} [get_pins {ext_pll_inst|altpll_component|auto_generated|pll1|clk[0]}] 
create_generated_clock -name {ext_pll_inst|altpll_component|auto_generated|pll1|clk[1]} -source [get_pins {ext_pll_inst|altpll_component|auto_generated|pll1|inclk[0]}] -duty_cycle 25.000 -multiply_by 1 -divide_by 2 -phase 180.000 -master_clock {clk1} [get_pins {ext_pll_inst|altpll_component|auto_generated|pll1|clk[1]}] 
create_generated_clock -name {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]} -source [get_pins {ext_pll_inst|altpll_component|auto_generated|pll1|inclk[0]}] -duty_cycle 50.000 -multiply_by 1 -divide_by 2 -phase -45.000 -master_clock {clk1} [get_pins {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}] 
#create output clock
create_generated_clock -name {clk_out} -source [get_pins {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}] -duty_cycle 50.000 -multiply_by 1 -master_clock {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]} [get_ports { CLK_OUT }] 


#*******************************************************************************
# Set Clock Latency
#*******************************************************************************



#*******************************************************************************
# Set Clock Uncertainty
#*******************************************************************************

set_clock_uncertainty -rise_from [get_clocks {altera_reserved_tck}] -rise_to [get_clocks {altera_reserved_tck}]  0.020 
set_clock_uncertainty -rise_from [get_clocks {altera_reserved_tck}] -fall_to [get_clocks {altera_reserved_tck}]  0.020 
set_clock_uncertainty -fall_from [get_clocks {altera_reserved_tck}] -rise_to [get_clocks {altera_reserved_tck}]  0.020 
set_clock_uncertainty -fall_from [get_clocks {altera_reserved_tck}] -fall_to [get_clocks {altera_reserved_tck}]  0.020 

set_clock_uncertainty -rise_from [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[0]}] -rise_to [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}]  0.050 
set_clock_uncertainty -rise_from [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[0]}] -fall_to [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}]  0.050 
set_clock_uncertainty -fall_from [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[0]}] -rise_to [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}]  0.050 
set_clock_uncertainty -fall_from [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[0]}] -fall_to [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}]  0.050 

set_clock_uncertainty -rise_from [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}] -rise_to [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}]  0.020 
set_clock_uncertainty -rise_from [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}] -fall_to [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}]  0.020 
set_clock_uncertainty -fall_from [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}] -rise_to [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}]  0.020 
set_clock_uncertainty -fall_from [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}] -fall_to [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}]  0.020 

set_clock_uncertainty -rise_from [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}] -rise_to [get_clocks {clk_out}]  0.050 
set_clock_uncertainty -rise_from [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}] -fall_to [get_clocks {clk_out}]  0.050 
set_clock_uncertainty -fall_from [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}] -rise_to [get_clocks {clk_out}]  0.050 
set_clock_uncertainty -fall_from [get_clocks {ext_pll_inst|altpll_component|auto_generated|pll1|clk[2]}] -fall_to [get_clocks {clk_out}]  0.050 


#*******************************************************************************
# Set Input Delay
#*******************************************************************************
#This delay is NOT needed since alignment between the rising 
#edge of the input clock and the incoming data is performed in
#the external PLL


#*******************************************************************************
# Set Output Delay
#*******************************************************************************
#This delay is needed to properly align the rising edge of the output 
#clock to the output data
                                                    
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[0]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[0](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[1]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[1](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[2]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[2](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[3]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[3](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[4]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[4](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[5]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[5](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[6]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[6](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[7]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[7](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[8]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[8](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[9]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[9](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[10]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[10](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[11]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[11](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[12]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[12](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[13]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[13](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[14]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[14](n)}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[15]}]
set_output_delay -add_delay  -clock [get_clocks {clk_out}]  2.000 [get_ports {DATA_OUT[15](n)}]


#*******************************************************************************
# Set Clock Groups
#*******************************************************************************

set_clock_groups -asynchronous -group [get_clocks {altera_reserved_tck}] 


#*******************************************************************************
# Set False Path
#*******************************************************************************

#set_false_path -to [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_0|datain}]
#set_false_path -to [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_1|datain}]
#set_false_path -to [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_2|datain}]
#set_false_path -to [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_3|datain}]
#set_false_path -to [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_4|datain}]
#set_false_path -to [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_5|datain}]
#set_false_path -to [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_6|datain}]
#set_false_path -to [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_7|datain}]
 
#set_false_path -to [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_0|datain}]
#set_false_path -to [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_1|datain}]
#set_false_path -to [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_2|datain}]
#set_false_path -to [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_3|datain}]
#set_false_path -to [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_4|datain}]
#set_false_path -to [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_5|datain}]
#set_false_path -to [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_6|datain}]
#set_false_path -to [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_7|datain}]


#*******************************************************************************
# Set Multicycle Path                                                                      
#*******************************************************************************
#These multicycle assignment are necessary to properly hand off
#data from the serial clock (fast clock) to the parallel clock
#(slow clock)

set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_0|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_0|clk0}] 3
set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_1|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_1|clk0}] 3
set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_2|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_2|clk0}] 3
set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_3|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_3|clk0}] 3
set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_4|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_4|clk0}] 3
set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_5|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_5|clk0}] 3
set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_6|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_6|clk0}] 3
set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_7|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chA|ALTLVDS_RX_component|auto_generated|rx_7|clk0}] 3

set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_0|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_0|clk0}] 3
set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_1|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_1|clk0}] 3
set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_2|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_2|clk0}] 3
set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_3|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_3|clk0}] 3
set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_4|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_4|clk0}] 3
set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_5|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_5|clk0}] 3
set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_6|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_6|clk0}] 3
set_multicycle_path -setup -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_7|clk0}] 4
set_multicycle_path -hold  -start -from [get_pins { lvds_receiver_chB|ALTLVDS_RX_component|auto_generated|rx_7|clk0}] 3

#*******************************************************************************
# Set Maximum Delay
#*******************************************************************************



#*******************************************************************************
# Set Minimum Delay
#*******************************************************************************



#*******************************************************************************
# Set Input Transition
#*******************************************************************************

